"""
Draft Sport Python
Team Constants Module
author: hugh@blinkybeach.com
"""
from draft_sport.fantasy.team.team import Team


class TeamConstants:

    SUPER_RUGBY = (
        Team('Blues'),
        Team('Brumbies'),
        Team('Bulls'),
        Team('Chiefs'),
        Team('Crusaders'),
        Team('Highlanders'),
        Team('Hurricanes'),
        Team('Jaguares'),
        Team('Lions'),
        Team('NSW Waratahs'),
        Team('Rebels'),
        Team('Reds'),
        Team('Sharks'),
        Team('Stormers'),
        Team('Sunwolves')
    )
